class sendAnimation:
    def send_animation(self,chat_id,animation,caption="", reply_to_message_id=0, reply_markup={}):
        res = self.send_request("sendAnimation",chat_id=chat_id,animation=animation,caption=caption,reply_to_message_id=reply_to_message_id,reply_markup=reply_markup)
        return res



import requests
import json
from .methods import getMe, sendMessage, sendDocument, sendAudio, sendVideo, forwardMessage, copyMessage, banChatMember, unbanChatMember, getChat, leaveChat, promoteChatMember, getChatMembersCount, createChatInviteLink, revokeChatInviteLink, exportChatInviteLink, deleteChatPhoto, setChatTitle, setChatDescription, pinChatMessage, unpinChatMessage, unpinAllChatMessages, editMessageText, deleteMessage, sendPhoto, sendAnimation, sendVoice, sendLocation, sendContact, setChatPhoto, uploadStickerFile

class Bot(getMe, sendMessage, sendDocument, sendAudio, sendVideo, forwardMessage, copyMessage, banChatMember, unbanChatMember, getChat, leaveChat, promoteChatMember, getChatMembersCount, createChatInviteLink, revokeChatInviteLink, exportChatInviteLink, deleteChatPhoto, setChatTitle, setChatDescription, pinChatMessage, unpinChatMessage, unpinAllChatMessages, editMessageText, deleteMessage, sendPhoto, sendAnimation, sendVoice, sendLocation, sendContact, setChatPhoto, uploadStickerFile):
    def __init__(
            self,
            token: str,
            base_url: str = "https://tapi.bale.ai"
            ):
        self.token = token
        self.url = f"{base_url}/bot{str(token)}/"
    
    def send_request(self, method, **kwargs):
        url = self.url + method
        files = None
        
        if method == "sendDocument" and "document" in kwargs:
            files = {"document": kwargs["document"]}
            del kwargs["document"]
        elif method == "sendPhoto" and "photo" in kwargs:
            files = {"photo": kwargs["photo"]}
            del kwargs["photo"]
        elif method == "sendVideo" and "video" in kwargs:
            files = {"video": kwargs["video"]}
            del kwargs["video"]
        elif method == "sendAudio" and "audio" in kwargs:
            files = {"audio": kwargs["audio"]}
            del kwargs["audio"]
        elif method == "sendAnimation" and "animation" in kwargs:
            files = {"animation": kwargs["animation"]}
            del kwargs["animation"]
        elif method == "sendVoice" and "voice" in kwargs:
            files = {"voice": kwargs["voice"]}
            del kwargs["voice"]
        elif method == "setChatPhoto" and "photo" in kwargs:
            files = {"photo": kwargs["photo"]}
            del kwargs["photo"]
        elif method == "uploadStickerFile" and "sticker" in kwargs:
            files = {"sticker": kwargs["sticker"]}
            del kwargs["sticker"]
        req = requests.post(url, files=files, data=kwargs)
        return req.json()



class editMessageText:
    def edit_message_text(self, chat_id=None, message_id=None, text="", reply_markup=None):
        res = self.send_request("editMessageText",chat_id=chat_id,message_id=message_id,text=text,reply_markup=reply_markup)
        return res


class sendLocation:
    def send_location(self,chat_id,latitude,longitude, horizontal_accuracy=0, reply_to_message_id=0, reply_markup={}):
        res = self.send_request("sendLocation",chat_id=chat_id,latitude=latitude,longitude=longitude,horizontal_accuracy=horizontal_accuracy,reply_to_message_id=reply_to_message_id,reply_markup=reply_markup)
        return res



from .get_me import getMe
from .send_message import sendMessage
from .send_document import sendDocument
from .send_audio import sendAudio
from .send_video import sendVideo
from .forward_message import forwardMessage
from .copy_message import copyMessage
from .ban_chat_member import banChatMember
from .unban_chat_member import unbanChatMember
from .promote_chat_member import promoteChatMember
from .leave_chat import leaveChat
from .get_chat import getChat
from .get_chat_members_count import getChatMembersCount
from .create_chat_invite_link import createChatInviteLink
from .revoke_chat_invite_link import revokeChatInviteLink
from .export_chat_invite_link import exportChatInviteLink
from .delete_chat_photo import deleteChatPhoto
from .set_chat_title import setChatTitle
from .set_chat_description import setChatDescription
from .pin_chat_message import pinChatMessage
from .unpin_chat_message import unpinChatMessage
from .unpin_all_chat_messages import unpinAllChatMessages
from .edit_message_text import editMessageText
from .delete_message import deleteMessage
from .send_photo import sendPhoto
from .send_animation import sendAnimation
from .send_location import sendLocation
from .send_voice import sendVoice
from .send_contact import sendContact
from .set_chat_photo import setChatPhoto
from .upload_sticker_file import uploadStickerFile


class forwardMessage:
    def forward_message(self,chat_id,from_chat_id,message_id):
        res = self.send_request("forwardMessage",chat_id=chat_id,from_chat_id=from_chat_id,message_id=message_id)
        return res  


class sendContact:
    def send_contact(self,chat_id,phone_number,first_name, lastname="", reply_to_message_id=0, reply_markup={}):
        res = self.send_request("sendLocation",chat_id=chat_id,phone_number=phone_number,first_name=first_name,lastname=lastname,reply_to_message_id=reply_to_message_id,reply_markup=reply_markup)
        return res



class promoteChatMember:
    def promote_chat_member(self,chat_id,user_id,can_change_info=False,can_post_messages=False,can_edit_messages=False,can_delete_messages=False,can_manage_video_chats=False,can_invite_users=False,can_restrict_members=False):
        res = self.send_request("promoteChatMember",chat_id=chat_id,user_id=user_id,can_change_info=can_change_info,can_post_messages=can_post_messages,can_edit_messages=can_edit_messages,can_delete_messages=can_delete_messages,can_manage_video_chats=can_manage_video_chats,can_invite_users=can_invite_users,can_restrict_members=can_restrict_members)
        return res


class unbanChatMember:
    def unban_chat_member(self,chat_id,user_id,only_if_banned=True):
        res = self.send_request("banChatMember",chat_id=chat_id,user_id=user_id,only_if_banned=only_if_banned)
        return res